@@ -11,12 +11,12 @@
 #
 
 Facter.add(:ps) do
-    setcode do 'ps -ef' end
+  setcode do 'ps -ef' end
 end
 
 Facter.add(:ps) do
-    confine :operatingsystem => %w{FreeBSD NetBSD OpenBSD Darwin}
-    setcode do 'ps auxwww' end
+  confine :operatingsystem => %w{FreeBSD NetBSD OpenBSD Darwin DragonFly}
+  setcode do 'ps auxwww' end
 end
 
 Facter.add(:ps) do
