@@ -26,6 +26,12 @@ module Facter::Util::EC2
       !!(Facter.value(:macaddress) =~ %r{^[dD]0:0[dD]:})
     end
 
+    # Test if this host has a mac address used by OpenStack, which 
+    # normally starts with 02:16:3E
+    def has_openstack_mac?
+      !!(Facter.value(:macaddress) =~ %r{^02:16:3[eE]})
+    end
+
     # Test if the host has an arp entry in its cache that matches the EC2 arp,
     # which is normally +fe:ff:ff:ff:ff:ff+.
     def has_ec2_arp?
@@ -40,7 +46,7 @@ module Facter::Util::EC2
       arp_table = Facter::Util::Resolution.exec(arp_command)
       if not arp_table.nil?
         arp_table.each_line do |line|
-          return true if line.include?(mac_address)
+          return true if line.downcase.include?(mac_address)
         end
       end
       return false
