@@ -1,7 +1,6 @@
-#!/usr/bin/env ruby
-
-require File.expand_path(File.dirname(__FILE__) + '/../../spec_helper')
+#!/usr/bin/env rspec
 
+require 'spec_helper'
 require 'facter/util/collection'
 
 describe Facter::Util::Collection do
@@ -93,6 +92,16 @@ describe Facter::Util::Collection do
 
         @coll.add(:myname) {}
       end
+
+      it "should discard resolutions that throw an exception when added" do
+        lambda {
+          @coll.add('yay') do
+            raise
+            setcode { 'yay' }
+          end
+        }.should_not raise_error
+        @coll.value('yay').should be_nil
+      end
     end
   end
 
