@@ -1,7 +1,6 @@
-#!/usr/bin/env ruby
-
-require File.expand_path(File.dirname(__FILE__) + '/../../spec_helper')
+#!/usr/bin/env rspec
 
+require 'spec_helper'
 require 'facter/util/uptime'
 
 describe Facter::Util::Uptime do
@@ -9,7 +8,7 @@ describe Facter::Util::Uptime do
   describe ".get_uptime_seconds_unix", :unless => Facter.value(:operatingsystem) == 'windows' do
     describe "when /proc/uptime is available" do
       before do
-        uptime_file = File.join(SPECDIR, "fixtures", "uptime", "ubuntu_proc_uptime")
+        uptime_file = my_fixture("ubuntu_proc_uptime")
         Facter::Util::Uptime.stubs(:uptime_file).returns("\"#{uptime_file}\"")
       end
 
@@ -26,15 +25,17 @@ describe Facter::Util::Uptime do
         Facter::Util::Uptime.stubs(:uptime_file).returns(@nonexistent_file)
       end
 
-      it "should use 'sysctl kern.boottime'" do
-        if [1].pack("L") == [1].pack("V") # Determine endianness
-          sysctl_output_filename = 'sysctl_kern_boottime_little_endian'
-        else
-          sysctl_output_filename = 'sysctl_kern_boottime_big_endian'
-        end
-        sysctl_output_file = File.join(SPECDIR, 'fixtures', 'uptime', sysctl_output_filename) # Aug 01 14:13:47 -0700 2010
+      it "should use 'sysctl -n kern.boottime' on OpenBSD" do
+        sysctl_output_file = my_fixture('sysctl_kern_boottime_openbsd') # Dec 09 21:11:46 +0000 2011
         Facter::Util::Uptime.stubs(:uptime_sysctl_cmd).returns("cat \"#{sysctl_output_file}\"")
-        Time.stubs(:now).returns Time.parse("Aug 01 15:13:47 -0700 2010") # one hour later
+        Time.stubs(:now).returns Time.parse("Dec 09 22:11:46 +0000 2011") # one hour later
+        Facter::Util::Uptime.get_uptime_seconds_unix.should == 60 * 60
+      end
+
+      it "should use 'sysctl -n kern.boottime' on Darwin, etc." do
+        sysctl_output_file = my_fixture('sysctl_kern_boottime_darwin') # Oct 30 21:52:27 +0000 2011
+        Facter::Util::Uptime.stubs(:uptime_sysctl_cmd).returns("cat \"#{sysctl_output_file}\"")
+        Time.stubs(:now).returns Time.parse("Oct 30 22:52:27 +0000 2011") # one hour later
         Facter::Util::Uptime.get_uptime_seconds_unix.should == 60 * 60
       end
 
@@ -44,7 +45,7 @@ describe Facter::Util::Uptime do
         end
 
         it "should use 'kstat -p unix:::boot_time'" do
-          kstat_output_file = File.join(SPECDIR, 'fixtures', 'uptime', 'kstat_boot_time') # unix:0:system_misc:boot_time    1236919980
+          kstat_output_file = my_fixture('kstat_boot_time') # unix:0:system_misc:boot_time    1236919980
           Facter::Util::Uptime.stubs(:uptime_kstat_cmd).returns("cat \"#{kstat_output_file}\"")
           Time.stubs(:now).returns Time.at(1236923580) #one hour later
           Facter::Util::Uptime.get_uptime_seconds_unix.should == 60 * 60
@@ -56,7 +57,7 @@ describe Facter::Util::Uptime do
           end
 
           it "should use 'who -b'" do
-            who_b_output_file = File.join(SPECDIR, 'fixtures', 'uptime', 'who_b_boottime') # Aug 1 14:13
+            who_b_output_file = my_fixture('who_b_boottime') # Aug 1 14:13
             Facter::Util::Uptime.stubs(:uptime_who_cmd).returns("cat \"#{who_b_output_file}\"")
             Time.stubs(:now).returns Time.parse("Aug 01 15:13") # one hour later
             Facter::Util::Uptime.get_uptime_seconds_unix.should == 60 * 60
